.. highlight:: shell

============
Installation
============


Stable release
--------------

To install PIconnect, run this command in your terminal:

.. code-block:: console

    $ conda install PIconnect

This is the preferred method to install PIconnect, 
as it will always install the most recent stable release, 
including the dependencies.
If you don't have conda installed 
(either using `Miniconda`_ or `Anaconda`_),
you can also install using `pip`_.

.. code-block:: console

    $ pip install PIconnect


If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/
.. _Miniconda: https://docs.conda.io/en/latest/miniconda.html
.. _Anaconda: https://www.anaconda.com/

From sources
------------

The sources for PIconnect can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/Hugovdberg/PIconnect

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/Hugovdberg/PIconnect/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/Hugovdberg/PIconnect
.. _tarball: https://github.com/Hugovdberg/PIconnect/tarball/master
